@@ -15,9 +15,9 @@ def knockout(values):
         field_names = values[0].knockout_fields()
     else:
         try:
-            fields = model.to_dict().keys()
+            fields = values[0].to_dict().keys()
         except Exception, e:
-            fields = model._meta.fields
+            fields = values[0]._meta.fields
 
     return ko(values, field_names)
 
@@ -44,9 +44,9 @@ def knockout_model(values):
         field_names = values[0].knockout_fields()
     else:
         try:
-            fields = model.to_dict().keys()
+            fields = values[0].to_dict().keys()
         except Exception, e:
-            fields = model._meta.fields
+            fields = values[0]._meta.fields
 
     return koModel(modelClass, field_names)
 
